==> mythstream_0.17.2.orig.tar.gz: mythstream-0.17.2.orig/libs/x11win.cpp <==

#include <iostream>
#include <X11/Xlib.h>


using namespace std;

//extern void handleExposeEvent();

Display* qt_xdisplay (void);

void myX11MapWindow (uint id)
{
  //cout << "mapping" << endl;
  XMapWindow (qt_xdisplay(), id);
  XFlush (qt_xdisplay());
}

void myX11UnmapWindow (uint id)
{
 // cout << "unmapping" << endl;
  XUnmapWindow (qt_xdisplay(), id);
  XFlush (qt_xdisplay());
}

/*
void listenXEvents(uint windowid, XEvent *xevent)
{
  switch (xevent->type)
  {
     case KeyPress: cout << "keypress" << endl; break;
     case KeyRelease: cout << "kr" << endl; break;
     case ButtonPress: cout << "bp" << endl; break;
     case ButtonRelease: cout << "br" << endl; break;
     case MotionNotify: cout << "mn" << endl; break;
     case EnterNotify: cout << "en" << endl; break;
     case LeaveNotify: cout << "ln" << endl; break;
     case FocusIn: cout << "fi" << endl; break;
     case FocusOut: cout << "fo" << endl; break;
     case KeymapNotify: cout << "kmn" << endl; break;
     case Expose:  cout << "ex" << endl; break;
     case GraphicsExpose: cout << "gex" << endl; break;
     case NoExpose: cout << "nex" << endl; break;
     case VisibilityNotify: cout << "vn" << endl; break;
     case CreateNotify: cout << "cn" << endl; break;
     case DestroyNotify: cout << "dn" << endl; break;
     case UnmapNotify: cout << "umapn" << endl; break;
     case MapNotify: cout << "mapn" << endl; break;
     case MapRequest: cout << "mapr" << endl; break;
     case ReparentNotify: cout << "rpn" << endl; break;
     case ConfigureNotify: cout << "confn" << endl; break;
     case ConfigureRequest: cout << "confr" << endl; break;
     case GravityNotify: cout << "gravn" << endl; break;
     case ResizeRequest: cout << "resr" << endl; break;
     case CirculateNotify: cout << "cirn" << endl; break;
     case CirculateRequest: cout << "cirr" << endl; break;
     case PropertyNotify: cout << "propn" << endl; break;
     case SelectionClear: cout << "selc" << endl; break;
     case SelectionRequest: cout << "selr" << endl; break;
     case SelectionNotify: cout << "seln" << endl; break;
     case ColormapNotify: cout << "coln" << endl; break;
     case ClientMessage: cout << "clm" << endl; break;
     case MappingNotify: cout << "mappingn" << endl; break;
  }
}

*/

==> mythstream_0.18.1.orig.tar.gz: mythstream-0.18_1/libs/x11win.cpp <==

#include <iostream>
#include <X11/Xlib.h>


using namespace std;

//extern void handleExposeEvent();

Display* qt_xdisplay (void);

void myX11MapWindow (uint id)
{
  //cout << "mapping" << endl;
  XMapWindow (qt_xdisplay(), id);
  XFlush (qt_xdisplay());
}

void myX11UnmapWindow (uint id)
{
 // cout << "unmapping" << endl;
  XUnmapWindow (qt_xdisplay(), id);
  XFlush (qt_xdisplay());
}


uint myX11GrabKeyboard(uint id)
{
   uint res;
   
   res = XGrabKeyboard(qt_xdisplay(), id, true, GrabModeAsync, GrabModeAsync, CurrentTime);

   switch (res)
   {
      case GrabNotViewable: cout << "MythStream: GrabNotViewable" << endl; break;
      case AlreadyGrabbed: cout << "MythStream: AlreadyGrabbed" << endl; break;
      case GrabFrozen: cout << "MythStream: GrabFrozen" << endl; break;
      case GrabInvalidTime: cout << "MythStream: GrabInvalidTime" << endl; break;
   }

   return res;
}

void myX11UngrabKeyboard()
{
   XUngrabKeyboard(qt_xdisplay(), CurrentTime);
}

/*
void listenXEvents(uint windowid, XEvent *xevent)
{
  switch (xevent->type)
  {
     case KeyPress: cout << "keypress" << endl; break;
     case KeyRelease: cout << "kr" << endl; break;
     case ButtonPress: cout << "bp" << endl; break;
     case ButtonRelease: cout << "br" << endl; break;
     case MotionNotify: cout << "mn" << endl; break;
     case EnterNotify: cout << "en" << endl; break;
     case LeaveNotify: cout << "ln" << endl; break;
     case FocusIn: cout << "fi" << endl; break;
     case FocusOut: cout << "fo" << endl; break;
     case KeymapNotify: cout << "kmn" << endl; break;
     case Expose:  cout << "ex" << endl; break;
     case GraphicsExpose: cout << "gex" << endl; break;
     case NoExpose: cout << "nex" << endl; break;
     case VisibilityNotify: cout << "vn" << endl; break;
     case CreateNotify: cout << "cn" << endl; break;
     case DestroyNotify: cout << "dn" << endl; break;
     case UnmapNotify: cout << "umapn" << endl; break;
     case MapNotify: cout << "mapn" << endl; break;
     case MapRequest: cout << "mapr" << endl; break;
     case ReparentNotify: cout << "rpn" << endl; break;
     case ConfigureNotify: cout << "confn" << endl; break;
     case ConfigureRequest: cout << "confr" << endl; break;
     case GravityNotify: cout << "gravn" << endl; break;
     case ResizeRequest: cout << "resr" << endl; break;
     case CirculateNotify: cout << "cirn" << endl; break;
     case CirculateRequest: cout << "cirr" << endl; break;
     case PropertyNotify: cout << "propn" << endl; break;
     case SelectionClear: cout << "selc" << endl; break;
     case SelectionRequest: cout << "selr" << endl; break;
     case SelectionNotify: cout << "seln" << endl; break;
     case ColormapNotify: cout << "coln" << endl; break;
     case ClientMessage: cout << "clm" << endl; break;
     case MappingNotify: cout << "mappingn" << endl; break;
  }
}

*/
